(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    116577,       2291]
NotebookOptionsPosition[    115083,       2234]
NotebookOutlinePosition[    115562,       2253]
CellTagsIndexPosition[    115519,       2250]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Example Notebook: GUT scale Flavour Data (Version of \
January 15, 2015)",
 FontFamily->"Serif"]], "Title",
 CellChangeTimes->{}],

Cell[TextData[StyleBox["This notebook shows how to load the data partially \
shown in chap. 5 of the thesis and use it for your own project. For naming \
and conventions, see therein. \n\nNOTE: \nIn order to avoid definitions in \
conflict with other open notebooks and similar issues, it is recommended to \
set this one\[CloseCurlyQuote]s context to \[OpenCurlyDoubleQuote]Unique to \
This Notebook\[CloseCurlyDoubleQuote] or quit the MathKernel before you load \
or evaluate everything.",
 FontFamily->"Serif",
 FontWeight->"Plain"]], "Section",
 CellChangeTimes->{}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Quick procedure:",
 FontFamily->"Serif"]], "Section"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["First, set the current directory to the one where you \
have stored this notebook:",
 FontFamily->"Serif"]], "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input"],

Cell[TextData[StyleBox["(This step is optional if you specify the full path \
afterwards.)",
 FontFamily->"Serif",
 FontSize->11]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Load all data:\n",
  FontFamily->"Serif"],
 StyleBox["All data is organized as tab separated files with columns:\n\ntan[",
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  OverscriptBox["\[Beta]", "_"]], "Input",
  FontFamily->"Serif",
  FontSize->12,
  FontWeight->"Plain"],
 StyleBox["]\t\t",
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Eta]", "_"], "b"], TraditionalForm]],
  FontSize->12],
 StyleBox["\tquantity\n\nThis can be imported using Mathematica\
\[CloseCurlyQuote]s",
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   ButtonBox[
    RowBox[{" ", "Import"}],
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Import"], TextForm]],
  FontSize->12],
 StyleBox[" function as \[OpenCurlyDoubleQuote]Table\[CloseCurlyDoubleQuote] \
data and then be passed to the ",
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   ButtonBox["Interpolation",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Interpolation"], TextForm]],
  FontSize->12],
 StyleBox[" function or directly to ",
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   ButtonBox["ListContourPlot",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/ListContourPlot"], TextForm]],
  FontSize->12],
 StyleBox[".\n\nNote that values are given even in the non-perturbative \
region. These cannot be trusted reliably, but are useful for interpolation \
algorithms which only work with full regular grids without holes. One can cut \
off these points using the  \[OpenCurlyDoubleQuote]largest_coupling.dat\
\[CloseCurlyDoubleQuote]  file and a limit for perturbativity. We recommend ",
  
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox[
     RowBox[{"4", " ", "\[Pi]"}]],
    FontFamily->"Nimbus Sans L",
    FontSize->11,
    FontWeight->"Plain"], TraditionalForm]],
  FontSize->12],
 StyleBox[".",
  FontFamily->"Serif",
  FontSize->12]
}], "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "file", "}"}], ",", 
       RowBox[{"Import", "[", 
        RowBox[{"file", ",", "\"\<Table\>\""}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{"\"\<data/MSUSY=1TeV/largest_coupling.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{"largest", " ", 
          RowBox[{"(", 
           RowBox[{"non", " ", "mixing", " ", "angle"}], ")"}], " ", 
          "coupling"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_yu.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          SubscriptBox["y", "u"], " ", "sin", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "6"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_yd.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "q"]}], ")"}], " ", 
          SubscriptBox["y", "d"], " ", "cos", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_ye.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "\[ScriptL]"]}], ")"}], " ", 
          SubscriptBox["y", "e"], " ", "cos", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "6"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\"\<data/MSUSY=1TeV/reduced_yc.dat\>\"", ",", 
       " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          SubscriptBox["y", "c"], " ", "sin", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "3"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_ys.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "q"]}], ")"}], " ", 
          SubscriptBox["y", "s"], " ", "cos", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "4"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_ymu.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "\[ScriptL]"]}], ")"}], " ", 
          SubscriptBox["y", "\[Mu]"], " ", "cos", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "4"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\"\<data/MSUSY=1TeV/reduced_yt.dat\>\"", ",", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          SubscriptBox["y", "t"], " ", "sin", 
          OverscriptBox["\[Beta]", "_"]}]}], " ", "*)"}], 
       "\[IndentingNewLine]", "\"\<data/MSUSY=1TeV/reduced_yb.dat\>\"", ",", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "b"]}], ")"}], " ", 
          SubscriptBox["y", "b"], " ", "cos", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_ytau.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          SubscriptBox["y", "\[Tau]"], " ", "cos", 
          RowBox[{
           OverscriptBox["\[Beta]", "_"], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "\"\<data/MSUSY=1TeV/sigma_yt.dat\>\"", ",", 
       " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{"\[Sigma]", 
          RowBox[{
           RowBox[{"(", 
            SubscriptBox["y", "t"], ")"}], "/", 
           SubscriptBox["y", "t"]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/sigma_yb.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{"\[Sigma]", 
          RowBox[{
           RowBox[{"(", 
            SubscriptBox["y", "b"], ")"}], "/", 
           SubscriptBox["y", "b"]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/sigma_ytau.dat\>\"", ",", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{"\[Sigma]", 
          RowBox[{
           RowBox[{"(", 
            SubscriptBox["y", "\[Tau]"], ")"}], "/", 
           SubscriptBox["y", "\[Tau]"]}]}]}], " ", "*)"}], 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_theta23.dat\>\"", ",", 
       RowBox[{"(*", " ", 
        RowBox[{"quantity", ":", " ", 
         RowBox[{
          FractionBox[
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "q"]}], 
           RowBox[{"1", "+", 
            SubscriptBox[
             OverscriptBox["\[Eta]", "_"], "b"]}]], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            RowBox[{"q", ",", "23"}]], " ", "/", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "2"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
       "\"\<data/MSUSY=1TeV/reduced_theta13.dat\>\""}], " ", 
      RowBox[{"(*", " ", 
       RowBox[{"quantity", ":", " ", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", 
           SubscriptBox[
            OverscriptBox["\[Eta]", "_"], "q"]}], 
          RowBox[{"1", "+", 
           SubscriptBox[
            OverscriptBox["\[Eta]", "_"], "b"]}]], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", 
           RowBox[{"q", ",", "13"}]], " ", "/", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "3"}]]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
      "}"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Define interpolated functions:\n",
  FontFamily->"Serif"],
 StyleBox["To study e.g. ",
  FontFamily->"Serif",
  FontSize->12],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["y", "b"],
    FontFamily->"Nimbus Sans L",
    FontSize->11], TraditionalForm]],
  FontFamily->"Serif",
  FontSize->12],
 StyleBox[" at the GUT scale, we define the following three functions. \
Indices of ",
  FontFamily->"Serif",
  FontSize->12],
 StyleBox["data",
  FontFamily->"Courier",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],
 StyleBox[" just correspond to the order they are stated in the list above. \
We recommend to set the interpolation order to 1.",
  FontFamily->"Serif",
  FontSize->12]
}], "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Interpolation", ",", 
    RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"largestCoupling", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"data", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reducedYb", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"data", "[", 
     RowBox[{"[", "9", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"relativeErrorOfYb", "=", 
   RowBox[{"Interpolation", "[", 
    RowBox[{"data", "[", 
     RowBox[{"[", "12", "]"}], "]"}], "]"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Exclude anything, where couplings become non-perturbative:\n",
  FontFamily->"Serif"],
 StyleBox["We make a plot showing what is excluded by demanding \
perturbativity, i.e. couplings below ",
  FontFamily->"Serif",
  FontSize->11],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SqrtBox[
     RowBox[{"4", " ", "\[Pi]"}]],
    FontFamily->"Nimbus Sans L",
    FontSize->11,
    FontWeight->"Plain"], TraditionalForm]],
  FontFamily->"Serif",
  FontSize->11],
 StyleBox[". ",
  FontFamily->"Serif",
  FontSize->11]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"NPboundary", "=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"4", "Pi"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"NPExclusion", "=", 
  RowBox[{"RegionPlot", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"largestCoupling", "[", 
      RowBox[{"tan\[Beta]", ",", "\[Eta]b"}], "]"}], ">", "NPboundary"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"tan\[Beta]", ",", "5", ",", "75"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\[Eta]b", ",", 
      RowBox[{"-", "0.6"}], ",", "0.6"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<tan \!\(\*OverscriptBox[\(\[Beta]\), \(_\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[OverscriptBox[\(\[Eta]\), \(_\)], \
\(b\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
    "PlotLabel", "\[Rule]", 
     "\"\<Excluded by non-perturbative couplings\>\""}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxllnlY1NUax5H0GiSQaaYhaAK3QZBIZRPh97IKMywzAxlRTmSkiAYESpml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   "], {{
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlnmUj2UUx++LshukMPZljKVQiqEwsmQmEolSpEkRISW0z0QqRnbCZIks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         "]], 
        PolygonBox[CompressedData["
1:eJwtk1tLlFEUhvenlVpWZqZWlvonvBC66sYLr0qwTNRGC82ckULRURMGESIY
gmFAgvB3VGhqpajdlIh28BSZp7ISyisPz2K/Fw/vWrP3N986vF9xKHItnOKc
K4Uj8APOB849QW/AJlwiT6JVMAlp5B1oJ0zDN6iHZpiCRbgNTTABJ7nfhV6H
bSgmH0SrYR0ukj9Fb8Ix4qPQRtwOo1BAnkCvwgr8h3t653vYhQaohB0IuN9q
Cu+giOA5Wg5v4DL5AFoGy6rZag3BTyjk/Bl6C76rx2a9YwjyOX+MlsAC/ING
9fwaLnAeR684X4T1ZL1E4BXkkffbPThFnA09xHfhDPEHtMX537ICf8fOuuEA
Tgc+DmuW4+ptUL3+Uu3W89nAP2N3H6m3t+rdetzXTmwX92EWZlRrLXyCXJ7p
QysghTgVHhI/cL7WP3BHNX+VR8wbdeapQDtx/pnfsKd32TPHOciEKHGNdrMl
rw1o9xvyRkKzX9WubQcZ5OmBn6V58gWcI4/ZbLWbL6qlUd5Z0q7NQ+b1Ye3S
PG9eH5PXktrlmvPfQlyzeKn/tpmYd0e0a/NwDvlH9dLrvJf/KjZPnwj8TmwX
UdU67/y3EZM3PmvW5pE5zdxmbd/QIWxPbOE=
         "]]}]}, {}, {}, {}, {}}, 
    {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwt0skyXGEAhuHWaNFtjBiDaESysczOysZClcINqHIBSFXuw1W4CFNIkEkG
8zxLzGMMSQjJc4rFU+///ZvuOufEW9ub2xJCoVAnLwnOHcwEZ+OnJmkiYWbt
dH2vc+Q6d+sZPeTZ8/qBBfLtXj2njwd2Kil8tJeocl7UC5Ypt1f0E2s8s1f1
knUq7A0d5TvP7U39xWd+UOCuX3/zmkJ7S7+wTZE9oH8Y5LG9o1/Zpdh+o1e8
pcTe02/sU2oP6TXDPLEPdIxDyuwR/cs74vaR3nLDMZXuTnScbOeHZJBFJv/c
52iMNKJMuHukp5qskYS7lzYp0zx1ntIWmnlFE400UE8dtdTwgurgvwTPKHi3
pBEjSmrwzkghEvxm8D2QSBfh++/mPxq9SLk=
      "]]}}],
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"tan \\!\\(\\*OverscriptBox[\\(\[Beta]\\), \\(_\\)]\\)\"", 
     TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Eta]\\), \\(_\\)], \
\\(b\\)]\\)\"", TraditionalForm]},
  Method->{"TransparentPolygonMesh" -> True, "AxesInFront" -> True},
  PlotLabel->FormBox[
   "\"Excluded by non-perturbative couplings\"", TraditionalForm],
  PlotRange->{{5, 75}, {-0.6, 0.6}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Make a plot of ",
  FontFamily->"Serif"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["y", "b"], TraditionalForm]]],
 " at the GUT scale",
 StyleBox[":",
  FontFamily->"Serif"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"reducedYb", "[", 
      RowBox[{"tan\[Beta]", ",", "\[Eta]b"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"tan\[Beta]", ",", "5", ",", "75"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\[Eta]b", ",", 
       RowBox[{"-", "0.6"}], ",", "0.6"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "->", "All"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<tan \!\(\*OverscriptBox[\(\[Beta]\), \(_\)]\)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[OverscriptBox[\(\[Eta]\), \(_\)], \
\(b\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<(1+\!\(\*SubscriptBox[OverscriptBox[\(\[Eta]\), \(_\)], \(b\)]\)) \
\!\(\*SubscriptBox[\(y\), \(b\)]\) cos\!\(\*OverscriptBox[\(\[Beta]\), \(_\)]\
\) / \!\(\*SuperscriptBox[\(10\), \(-2\)]\)\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "0.54", ",", "0.55", ",", "0.57", ",", "0.60", ",", "0.65", ",", 
        "0.75", ",", "1.06"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"largestCoupling", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "<=", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"4", "Pi"}], "]"}]}], "&"}], ")"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", "NPExclusion"}],
   "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxkXQVYFUsURuxCVGxFUBAQhEs3e+iGC3aDrc/A7sTCQOxWbGzsdlEMQEVK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    
    "], {{{}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0slvzVEYh/Fzb6u0t03MykLUDisUC9StIcakUm6sTDXT3tZVqr1dIEFa
iam3LAlbw6K1wd487FBDSCW60fYf0PqcxZPn/Z73nPc3VjU012cTIYQBpEtD
mF0RwhxU4llZCMOpEEYwio9ylz3t/Kk8hC/4jDPyWax1po3b7XnAm+WH3IFO
rJPz3K3/nj/gOd7hLQbMKrhOL26gBzexW28vVjq/J85z/gCvkg/yPjRgp7yf
n6IHm+QCH8IRrJYPc975E1wjN/JRHEdGPsZf8Qhb5MfchGaskbPxWZw/xbVy
K7cgh7R8kr9hMpbJU+K92D+Nl8tT+YI8jqC+w2Oo1/vH361Nxwp5BhesVXsH
feqt1vp5CH9wMd6Hd9aKXPwOOI271mv059pfpx6M74bnyWl1rzrJi+UEX5KL
eIlczPfkWq6SM+rf6l08X16vPo8N6nOcdL0EAibIbfwq/g9cwkVcHHvokn/y
L/ThCfrx1+yEeUmMxVk8zinPfVWvibNoxJA805yF9txSV6pv8yJ5lvo13mAS
SnFfr9OsifG/5Dw68CO+E85gB4bjN+ARTuktNa+ML8vlXC1X8BVsVHfzoP11
/IK380setb/FfeawIP4PvI2vWy/Rv8b/AU5vavo=
          "]]},
        "1.06`"],
       Annotation[#, 1.06, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0klsjWEUh/HXSntvm1hRQiiRlAWhFhIJC2pDaiiiRVXNU0vsW9VWJL10
WKmuxJQrQWvBjoSaSUgJSYmQGG7YaLVVreH3Lp485/zPed/vu19ufmX12qox
IYReLM4OYW5uCOeTIWTlhDAWrbJ5+s5ECOPMuvgzPqHGrMzOJpRiCzajQ57g
JC44exFLZB+cKeK0vsWsGQWybG6TV3A/l3Mfb+WjXMk/eRsP8HFnlnuXRu6V
zeJWns1tnLHTwQv07VzIZ7iW+z27Dz+wQ7Yd9+U7eVd8jnwATe54q69R16Ia
32SlfAR7zfbhl3oYJ82a9Cke0g9ij343vsv28yD/lo9gFNM89x//xR8MmT+Q
1cU9jOAKqpwd5gPxeXyQP9obVVerD+MQ0vr57inEdfMC36hellE3cJ2dY/Gb
ogH1uCq/gSl2i3mm3RKeqr/JM/QL1dP5sn6OOl/9EI3OT+IczsVZ8xS/lr3B
K3TJznmfcrzUd+oXqa9xj/4E3jtzWtaOFE7F74keOyW8DuvRjbL434r38SO+
7ewtrIjv7d3y1BNRYTZBPx7NZl9lLZzhlXyPi/kOd+Nu/Kbxv4BlKMJSvPOc
LHdcsvvYnU+Qhw3xd8vT8f/LSSQw2ey5c6uxBqvwxR0veKPdp+bP8B8wnYA9

          "]]},
        "0.75`"],
       Annotation[#, 0.75, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0rtL1lEcx/Ej5GClj+ANTcsH0iFSHFMUAhtElxKy8jIkLi72F5ibZoOg
gy7eMvKCDmpGpUXlfdJwEy9DQYGTDTr3OsOb9/f7Od/zO+f5Pb9k+4vGrpQQ
whzep4XQez2EoqshZPE7fQ8n9N2cwS+5W/4PTeqneIJ5/e1rIZSg1dwe7+Mn
aqy9NvOAZ/UzyNFnY1rWz7fs6eOb/Ip75FvqfJSlhzAan69e4Qr9B15AmWeV
Y8jamX2DPCu/G8/hPFku/uIPzmQHZsb5nplKfNZP8id+w2PWPsZ34JwcZGNA
X2VtgzexrK4zN8ENXGhmXH0fLWhGW3wXuIM+eyr4G5+7xwi/5Uqe4xqe4ep4
fz7FCYbtGUF/vKszdpyVlO/yBV9i1doaGmWB1/ED3zHheal8BbXqRfPLWMKB
+YfyR3Fv/G14JkvjXexgG1P2ZXIC9eo1e7/iCw7NH8mPcYLn+izuiP+X+06b
z9Pnxu/B/GN9A/+yXs+/4zchKzXbqS4wdwPzsnRZAhkoliXxHxNZWOI=
          "]]},
        "0.65`"],
       Annotation[#, 0.65, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TssnWEcx/EHi7rEJUy6SCOIwSVxWxhLSxMiMUmExUIHJBI2NjGeo8XA
STvpJIhInCJsSCyCBYuFM0i7uIXPO3zz/V9+z/O+b97Sge/dI2khhGkMfwhh
AqnsEO5xq/6WE8IQl+WG0JsVwo26zeya27nH7ISL5IvxW/9JdtC+UN/Po7hU
X+Bc3Szfx4f6dvlt/Zm+hutQiy1k2r/wK56xLJthlo6/SGIHT3aPOHZHOR9x
l3eYtfujX8Wbs/95kf/xEj/hEZ3ym7Id+IovODBbkUtEz0VTdC66A41olVnH
Bh70n+Vb1PvqvSij3jWbd/YHYtG3mcd5hqfsq3mSa/jePIU7xPVJ7KDaPsaV
XIEFdyb4J5+aN6jrMa0u9M2bXMAbfIVrzCHPvfkoQJX8r+j/qMfVH+3HuITP
sGb3DubQTQM=
          "]]},
        "0.6`"],
       Annotation[#, 0.6, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0bsrhXEcx/HfWci1/AFI6lhcshhcchtYECallEVKDIrJyMRm4pxjcFko
LC6LS8qCQZxNWRyKOLKwkNczvHv/vp/v5/ecnudUjE4NTMZCCNNozgvhqTCE
DFYKQljMD2GVh7iSi+UjnEQCcfmSrIpnzEfux7kKZ7IpcydenXdk22hBjfkD
71h2v57n5H1FIZzol8pO+YOz2LXbwz6yup9oQMIuhSS+zGs8r7OAcucyXHjO
uLnRftPcxFt8Ke+R90a/i2P0y37t/5DCd/Rs/uGY/S7XoBbVuNWv4y6dA+7m
Q07L7/TvkcawuSj6ftjQyfGe65zLJbJzd9rQjlY86HfwoM4V3+Aaj/KM/jNe
MBa9Q/R/Rd/Y/IZZ5wn8A6uDRHg=
          "]]},
        "0.57`"],
       Annotation[#, 0.57, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVz78rxHEcx/GP/Mqvv4ABg+VkchgOkSghbpCY3HCDqyNiUAwoslCWMyqT
YlenpAxY/B4oAwZiocjoccOz5/v9+rzf72/fmsRkPJ0XQphBqiSEObyXhfCG
V3VfeQhJftW/4BlP+nN5vDSEMx7iNn6Ux/iBW7lffszNaEEjmhDFIcrdKqgI
oRD52DFfLCvCiBvTuFZf4VIdsTPMWf2Beh8X+jo+50E31r21u5PiU1m1twn1
Glaxq//z/s0Z/uJt/sUPeu1MocdsN07Uydz3sIyomWHfWVEfeauyn+UB2bys
wfuW7IM/EUFMvpe7Z+5B38FpdMo6kECl/XHexAZu3Bgze82jXJv7Bzt3+nvc
Yla+iC67C7yEenXG3D9Bq0CZ
          "]]},
        "0.55`"],
       Annotation[#, 0.55, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzr0uQ3EcBuBfR18XgKgoQsVmq620JSERESQdJKUhBo2kgg0X0AtwCScx
Gepj6mipRVoWH1dhYPAYnrznff8n53/GKrX1o1REbJDviXjrjWj0R5z2RZyx
y5B+72zP86zzc7k6EPFgG3b2KC9tV1xwQ5WWfUEuUuCWZdu+PGDpv3NsW+Hb
t9fkna3Jtf7LD4l7xpkgw5P3JmXeWVa29Wn5LGdkwZ7zj0X5Ytv0vS22Ketz
3unKjt7llR09Z5/nXf+gbqtQtJX4tH1xYqsy6PlQTrkrcVdaH2GUP/C5K9w=

          "]]},
        "0.54`"],
       Annotation[#, 0.54, "Tooltip"]& ], {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxllnlY1NUax5H0GiSQaaYhaAK3QZBIZRPh97IKMywzAxlRTmSkiAYESpml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    "], {{
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlnmUj2UUx++LshukMPZljKVQiqEwsmQmEolSpEkRISW0z0QqRnbCZIks
jXUi2vflj7bTvu/7cqpT57R3ut9zP+/5zR/fc5/nvnd77nPvfd42RTNHzahi
ZsMSs6pONztKHOc4mjhqO+o4ii2+Zznqs67maAA9ytEQerTjGGh1RyNoDcex
0JqO46C1HO3x19TRGJ58t2Ovb7c6RhPDXOJo5mjOugH6ireuoyUxKZZWUMXS
GqpY2kAVS1uo/LXAnvTPxUeOY5fjdsdYR2dsyUYuOvLZESqfnaCS64Ks/OxA
p5vjeHg66wlQ5WOMo4OjK7Q5Pu7DR3fHSfhQLD2g8nMyVLZPgcr2iehK5zZs
9HLs4Vueozdr2e4Dle1TobJ9GlS2S9HrV+nM8rHGMdhR4MjHruwNgMre6VDZ
u8exwnG+Y7mjv2OQ4370ZWsIa9k4AyobqkfVgGpjq2OtY5xFLRc76jnORF96
2xxljgscGxyFjuGOB5DR/kJ4Ixxnsz7LcaNjuuMyx3i+jXTMdkxgnfaGYkp7
Q/vG3K/uuxb7tA9EVYtp/0gn7R/t1Q9N0FEvqAey8aHaUC/sJ8/KnfqgKTpp
7zUijhboyEdL9mlvtLJMb7S2TG+0wVZ7ziB91aX6YopjokWvpP2W2s1FLu0N
7bc4ljjOc3wsns+fIvyphjvhU3XbxTK9of1UC1n1h/oo7Y+01lWX6lHVd09s
qYZV0+qdbsSQ9kkP4tL37pbpJemoL3rBT2s33zK90dsyvdHHMr2hvWpZdTwQ
25JN+yufO1IO1D99LdMPA7jHfsir/gchLz3V52DL9ID2qmXV8TCL2lfvDbWo
5wLL9I56oBCollXTCxzzLWar9qpn1fwMy9T4VY5ZFu9Cc+5Z9XYx6xzuYAzr
nRYzUnez2LGIu17mWGrR45cgL5nVjlUWPbvJsdGi/y6Fpj04nvV6xzqL/p0M
fyRnKuScimsicV5OrDn4LGI9jTi6Eu8k1kXo5PB9Kno3kRf5nE58I7A9BZ/j
yZv4E5Adie1p2Fc+r3YkyE5HfjL2ZeMix0zHKIvZcg325PMK8nI9tnQvm7mj
KsjORncWMvI1h2+jsD2HtWaI5kkWObuWvM2D3wyqfTbf58FXvDdwDtVRMXau
I1+T8Xkz8W933IvcLRYzuh78EuIv4ZvONRq7WdAFyC+0mIPZ2JoPfy58ye92
lFvMgkVQ9fMdFjOiJ7IL8aMZp7nQGV3JdINKZ2wlW9KtcByw6PM7Lfq5L1R7
1fw+9vKrN0713w8bi7Gjnr3Lov5LkemL7t5KvFJ0tV6GzCHHQYue19unPtK8
WGkxgwbyTf0ylO+r4a/jWwH+11aSWY6dQ/C13oZOAbyt8JdyNvX1EYt5JJm7
WQ9Dbz32JXPYYmaVIadeVk2r94dDN6H7ukMFPBOdjfArOGM/eBvQVc1vtqif
VcQ5jpxv4V5WELN0S5CvQpzbiEd1uh1+GfwC7nMLd1qMXFVsrrTMP8wq8lyC
HcnqH1LzMa2rXax3sh4LX/WnWtPboXdIb5Der3LkO7LPhbcbfjn87uiXs96L
nTxiU93qTSnlWx50H+dawrqUc1Wgtwc5yezHjnLYm30evAr4B+DLl2aC5oHm
wA7OrHmoN041rFrSm3WYPA9hr/frHcfz3Oka5AcjKxnN/Q3sC6FHsJOLvw74
3EGu8vHdH3uHiKEMXdn72vGSRc1863iZ+/3e8YpFXa1FV3F96XiRe/zF0SiJ
2fej41WLunrP8YLFzDlIDDpLdZetmcRs/Vx3nMS78b5iT2I2S+9ddH9zPGwx
Ax9z/GExT/5yPGlRe786HrSYjfrP+sTifXvDkZPEO/Ozo30Sb8tnjnZJvHsf
Odom8b6p3hdx78rHV+Tkd2KdhL03LWwq9i/gK2ffkDfZ/tTC/iOcIRs/H1r4
eoi4FXNV51dL4r3U+R7ljMrHBxY5+cfxrMVM0J18x73oTD9ZnKuur9+2eDP/
djxtMYtec9RKoiYTp285vZK7+oH7auj8Bkn8+z+DvnSznFc/iffvKfKunD9H
TIqnRhLn1Bn/dDxuMbf/dfxn8ZY/wTfx67h87SR65X+Su3iK
          "]], 
         PolygonBox[CompressedData["
1:eJwtk1tLlFEUhvenlVpWZqZWlvonvBC66sYLr0qwTNRGC82ckULRURMGESIY
gmFAgvB3VGhqpajdlIh28BSZp7ISyisPz2K/Fw/vWrP3N986vF9xKHItnOKc
K4Uj8APOB849QW/AJlwiT6JVMAlp5B1oJ0zDN6iHZpiCRbgNTTABJ7nfhV6H
bSgmH0SrYR0ukj9Fb8Ix4qPQRtwOo1BAnkCvwgr8h3t653vYhQaohB0IuN9q
Cu+giOA5Wg5v4DL5AFoGy6rZag3BTyjk/Bl6C76rx2a9YwjyOX+MlsAC/ING
9fwaLnAeR684X4T1ZL1E4BXkkffbPThFnA09xHfhDPEHtMX537ICf8fOuuEA
Tgc+DmuW4+ptUL3+Uu3W89nAP2N3H6m3t+rdetzXTmwX92EWZlRrLXyCXJ7p
QysghTgVHhI/cL7WP3BHNX+VR8wbdeapQDtx/pnfsKd32TPHOciEKHGNdrMl
rw1o9xvyRkKzX9WubQcZ5OmBn6V58gWcI4/ZbLWbL6qlUd5Z0q7NQ+b1Ye3S
PG9eH5PXktrlmvPfQlyzeKn/tpmYd0e0a/NwDvlH9dLrvJf/KjZPnwj8TmwX
UdU67/y3EZM3PmvW5pE5zdxmbd/QIWxPbOE=
          "]]}]}, {}, {}, {}, {}}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwt0skyXGEAhuHWaNFtjBiDaESysczOysZClcINqHIBSFXuw1W4CFNIkEkG
8zxLzGMMSQjJc4rFU+///ZvuOufEW9ub2xJCoVAnLwnOHcwEZ+OnJmkiYWbt
dH2vc+Q6d+sZPeTZ8/qBBfLtXj2njwd2Kil8tJeocl7UC5Ypt1f0E2s8s1f1
knUq7A0d5TvP7U39xWd+UOCuX3/zmkJ7S7+wTZE9oH8Y5LG9o1/Zpdh+o1e8
pcTe02/sU2oP6TXDPLEPdIxDyuwR/cs74vaR3nLDMZXuTnScbOeHZJBFJv/c
52iMNKJMuHukp5qskYS7lzYp0zx1ntIWmnlFE400UE8dtdTwgurgvwTPKHi3
pBEjSmrwzkghEvxm8D2QSBfh++/mPxq9SLk=
       "]]}}]},
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"tan \\!\\(\\*OverscriptBox[\\(\[Beta]\\), \\(_\\)]\\)\"", 
     TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Eta]\\), \\(_\\)], \
\\(b\\)]\\)\"", TraditionalForm]},
  Method->{},
  PlotLabel->FormBox[
   "\"(1+\\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Eta]\\), \\(_\\)], \\(b\\)]\
\\)) \\!\\(\\*SubscriptBox[\\(y\\), \\(b\\)]\\) cos\\!\\(\\*OverscriptBox[\\(\
\[Beta]\\), \\(_\\)]\\) / \\!\\(\\*SuperscriptBox[\\(10\\), \\(-2\\)]\\)\"", 
    TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Analogously, a plot of ",
  FontFamily->"Serif"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Sigma]", "(", 
     SubscriptBox["y", "b"], ")"}], "/", 
    SubscriptBox["y", "b"]}], TraditionalForm]]],
 " at the GUT scale",
 StyleBox[":",
  FontFamily->"Serif"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ContourPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"relativeErrorOfYb", "[", 
      RowBox[{"tan\[Beta]", ",", "\[Eta]b"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"tan\[Beta]", ",", "5", ",", "75"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"\[Eta]b", ",", 
       RowBox[{"-", "0.6"}], ",", "0.6"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "->", "All"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<tan \!\(\*OverscriptBox[\(\[Beta]\), \(_\)]\)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[OverscriptBox[\(\[Eta]\), \(_\)], \
\(b\)]\)\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
     "PlotLabel", "\[Rule]", 
      "\"\<\[Sigma](\!\(\*SubscriptBox[\(y\), \(b\)]\)) / \!\(\*SubscriptBox[\
\(y\), \(b\)]\)\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{"Contours", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "0.0111", ",", "0.0114", ",", "0.0120", ",", "0.0130", ",", "0.0150", 
        ",", "0.0200", ",", "0.0330"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"ContourShading", "\[Rule]", "None"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RegionFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"largestCoupling", "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "<=", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"4", "Pi"}], "]"}]}], "&"}], ")"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", "NPExclusion"}],
   "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxsXQdUFMnTx4BiPPQQRVEXA4IoLjkztbDktIue4pkwZ8XzzIkz/T0j5qyY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    
    "], {{{}, {}, {}, {}, {}, {}, {}, {}}, {{}, 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0kdwTlEYh/HLGEyiRUtIlDCIbpRRhhGJLQtlRC8zOglJRBLRSZTIIrqd
wYYZZUGizKgrRBc9epSFzhK/s3i+5/2/7znnzr3fSZ6TNS6zThRFcX7yYqNo
dKMoWsmbsapJFG3iVL02nCvn82B5HmfJTXk+miBTnsv9zRfwMjmOF6E5lssL
eYj5g8ZRVKTexJtRjNXyH7My6zqpd+h15mt6ybxb7s47OYV38WJez+uwFh3l
rfyQC5HnrHbhXZCEFXIBD3Dma26LLepEfoM26nhrqtXbnLMdpXgb9vMOfs1l
XI8n81N7nmCPfJD3cg/9fOdUysvlbDxSP0Y1Msxv6P2LiaIa+SVeYJr+K25t
Fo8ncolznvJY/TEoD98Ater3qHJGqTXv1Pvt2Yee5mflFernPFV+xlP4pl4U
3leeHt6HZ/BbLjS7wL3k63wIhzFb/syfcMCa3vJFdZH6I8+SP/BMrtKrw9/D
u/M3zuYf4b14g/mRMOfhGIFRZqM4FX9x1PySXgu+Ly/lu7yE73Fd/mWewz85
l3+H/443mh/jyDdJU6cjzSwdJ/TX6R/nGrREtpzJA8P34hw5IfwPOBnul3wq
3HdUogIv0SrccQyy75Zn3A53GGvQTP8OfzH7isu4iitoH+4Wdwh3z5oSJMvn
EKu3l2N4pX4eMjx/UkBvmFkj3scFZvk4H85CinooTwx3PnwbORd71G3RTZ3E
XTiRu/JITsA4eyZgPOLl0ziDCuxGQ88s5hLURx/Uunfl3AD90Bf/AdK7kYk=

          "]]},
        "0.033`"],
       Annotation[#, 0.033, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0TlPlFEYBtBLYQgq0KARMATCjBtDx5KwGCODLEYWCxLFSihMTMCOxESl
MigFg9roDA1QKo1GINTyC1AW0U7cEGxlEc5XnDz3XXLvN5my24PXB7JCCDMs
Hg0hdjyE0bwQ4vIVL4kfC+FLbghfWWOdz+Tof5LLfGSVFc7oj8kUzxinggS/
zc678xxpfqlT0ZuyzPynLJU/ZLnvyJb15g1MkOECFTw0G+eBvZT8zlmG1Buy
xs5JHquXol3nBJVsqWP62zIuM3LTu2n5R5bY6dFfVp+SK7JQTsi/5lNyS07K
bVlq/4b5TYo4TTHT5nvm+/xjl51o3+xAvmGG11yyW6VfTVLdzJL/pNfdq7JV
3RLdE/02O+9lrdyRbfrtXKXPfj//9UfM9+Ud9YF8og7OC86Nzhepo4F67prl
yTn3zDMb3Wn3sl4T19QdfPM99+x2O3fRSa46aeeD/fvRPTxV58tFvVbnNppp
4QqPzIbpdO6igwL1C57zjrfRO/on5IB3Bjnivl69WxwCqY1eeg==
          "]]},
        "0.02`"],
       Annotation[#, 0.02, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0EsrrWEYxvGH7bBz9gGQQw4hx6XYA5QhJeVYimWApRgrlIEyYPkGYsge
myP2JmYmyoDsbeRQSMnI7x38+9/Xc1/P865WaXxhYD4lhLCKk6wQKnNCKMdf
nOEcm6jIDiHJW3gyV/GpfkVuCM9yOZfhDuvyUp69TlL+w2WoMf+3K7V74CJ5
gx94i++jPf5Fb+kUcwnSsSLHdLbNbdH35Wq0yjFc+i39vvHL3IF2vOrV6uzw
oN0b18nvXM+73MwtaEATGjGs++n+Pn5jD526Hxi3v/KtMZ1rnpA/ncflSRyY
M5z9RCZ65BH3R/Glf4NpvVuO26eaD3V+8JR85zxhPnLWLaebOzmNu3iB87kA
x97s1TviPs6xm3H+6I1F80v0llxoXsEyLvTWnF3yEGbdTWAu+r/0vwEma0PP

          "]]},
        "0.015`"],
       Annotation[#, 0.015, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0Lsvw2EYhuGvDgutxV9gMRiaOEyGGsRikRQVE+oUkVRMDCZF4rALAyPF
hBVDJRKSRiwSg8lEJCLUYRDXb7hzP9/7Pu/yNWRn0rlYCGEWpdoQluMh5LGE
ekzXhfBWE8KC/MrjiRDGMIq0/iXyOkWe05lHLSbNnvVz8hP/IetmBN26CfsL
jvM5T+mdcYxHzB71J+QH/sGAuww6dartT7mKT3hY75i/MGR2rz9odsff6HfX
h1TU4QKXeZ8zenucdPfBKfMO3LrrtStxGUfyIdp1Xuy3+Zm3uMd8kxujv+IW
81bcuOu2u+ZPHMgFtOlU2q9xBa9yV/TvHLxXeNc7KV+5S8lFfkezvIH1aK/3
y4u8w036/5euQlM=
          "]]},
        "0.013`"],
       Annotation[#, 0.013, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzz0oxHEcx/Efw5WHO5LsRhakOIPB4ulOcZmdFGXwsGAweFiMyiADJXJ3
A+Upk8nkpAzKJoNJmTxEobz+w7v39/P9fv/f/r/6sZnMdEkIYQGxihBm4yHc
c10ihDuOy1VIYFn+qgxhib+5E0/6P/yLHfU2WsxLeMONNfWuWZN8y61yngv4
KA+hiF51i3kz9tSbdtKcwovelhzjdfeS6n11BzfIjWiT25HEkG8yyJm/yR94
x7DeJ+eQxwE67RT4MPpfd464lLv42P4JTtFt58F/jqiz0VvNk/Z+uIPH9cq4
HOd2u/XPuIcr9C6j98iPblxwn5zlUfzpPWMqeitPRHfU85hDrXxlv2h3kK+j
N3K12aTZq28W1Td6A3KNup/TSGFFXsU/fElBAA==
          "]]},
        "0.012`"],
       Annotation[#, 0.012, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzbsrxXEYx/GvzuRy5LKgKH+AyGJgUm6TOlLiHINyGQ4GFhaRxWBQTMot
bByUgWJyOTJgMDEZOJtBkXJ7Gd69v8/n8/yeX2XfaGwkK4QwjNecEIaiIQxi
AJ25IVxhNj+ENF/K2vmML3COYt1YXgjjyEa/OeNO0vuJv9BrL4FW3x7yoyzO
PehGk/wYM7494gNZI6d4H3uI6OJuJvCu6zXfu9NlvuMPdNiLoUG/yTeylH4X
O6iXr2LKtyu8YafuP+N1rCGDNrsvvKh75iVukTUj7eYbtr23UKu75ip73/yL
H9TIl2XVPOF/n7JJnjYvcKHu1ruA77iISzCvi5iT3g9cbq5AmbkUUdmcW6c4
wR+RNEDm
          "]]},
        "0.0114`"],
       Annotation[#, 0.0114, "Tooltip"]& ], 
      TagBox[
       TooltipBox[
        {GrayLevel[0], Opacity[0.4], 
         LineBox[{2916, 3308, 2914, 3307, 2915, 3309, 3451, 3355, 3037, 3615, 
          3036, 3437, 2820, 3693, 3348, 3692, 3349, 3347, 3026, 3605, 3339, 
          3281, 3282, 3280, 3336, 3335, 3601, 3278, 3279, 3277, 3519, 3518, 
          3517, 3516, 3514, 3515, 2811, 2785, 3520, 2791, 3684, 3080, 3186, 
          3185, 3602, 3337, 3338, 3283, 3523, 2894, 3284, 3015, 3340, 3728, 
          2899, 3530, 2900, 3285, 3021}]},
        "0.0111`"],
       Annotation[#, 0.0111, "Tooltip"]& ], {}, {}}}], 
   GraphicsComplexBox[CompressedData["
1:eJxllnlY1NUax5H0GiSQaaYhaAK3QZBIZRPh97IKMywzAxlRTmSkiAYESpml
F0GiSK9cEYNIE9HUWFxIiLCDICATKIssKnuUhiSIXlJZvN0ffc88D/EPz+eZ
83vf73nX88LaSOU72lpaWpIpWlr//2/apNY2VDvTK63SmcuW/cyCjukUHF7p
wtm4J/dXm9lunHuNlPPUt905n3xtWKYq9+QctT9j+1CGF2fbeufTidFSzqMz
fv75eakP5zKvT+bkv+DHOSnBwtvtoT/nF7tunt94S85Zd9yhxeaqgnO/4eeD
j5nyb/qLouQhV5Z0c/1g6AdDPxj6wdAPhn4w9IOhHwz9YOgHQ/9kvbbP5Kha
5B1cLxh6wdALhl4w9IKhFwy9YOgFQy8YeifrGXUtHDXwvM71gKEHDD1g6AFD
Dxh6wNADhp7J/stiyjK8HJu5fzD8g+EfDP9g+AfDPxj+J/tLyq61j7Nu4P7A
8AeGPzD8geEPDH+T7WeePJ0bI6vh9sGwD4Z9MOyDYX+yPcmMS7/12lzk9sCw
B4Y9MOxN/n79jRJZDhXx78H4HozvJ58fXdn4iZHF15p6+It5PUz6vXmCBfw+
mQMn7HM2ntArbEkqzGiREyWK8e5hjhdfr90ocaU+8fsuVuWYvTS1xYPSxXi1
sd3ve70jyV9Fb4r2WlnA2f4DJYneZCbau8rmDexVy1Uyui1+X8c6F9uM9dr4
0lrx/CV2dN21l7bq+dMd8ffSv+pJTkMin2Jzxe8VpCX+HSkZEfOvpK6J3wVw
78T3/D5BE/YFzBPohX70D/oZ+nEf1Df6C/eBHsQT8Z6sB/Ftthwxy3/Lg9Sx
y5sueN1gRVJfYauvJ1kZrDBVuV1jmWGHgtwcVtHeb4SYR04tbHvi3ff0zLzo
vuBRlmbfxL5ev9JdZaKgctH+XiEl9he5W7qCZKL948LOXXvWSAyU9Lyor0DY
nGoXrrdLST+I+isFl8IPfpN3OPF9gfyCp9+bP/+X7wSKcJ5hdv10D8N+BCOe
iC/sx4n1UcYZ9TNFzJM7rxcw5ueQ/okZv2xxp7AOq0Qzv3YG/XvE/JQI0IP6
Q3xxP9wf8cb3iDfiD32oX9jDvgSvOxDyTUkl0SHdf/tI8rt5vWM/Sb87U5p4
xoXqm2dujs3p4vsK97NsnHpdftCVpnma230a0MnrHfWC+Qh2L9uffXjUm1aL
8W/k5zHfJGK/S6lY9F/P+wX9g/kHnoiPjBzE+F7m5zHP7oj586HHYr2reb+h
/zDvwHUOHTrqb32pYqJ++HnMs4JXrU1SD/hR8kR8eb+ifzHvwGlbdq5UxftT
1kR++XnMt/PefYtT7eRkOZFf3l/of8w/cF7QPrutuXKKmqh/fh7zD/1i4CT2
C88v6hnxQnxxX8QHenE/+IM+1Af6B/UB+5h/k+ch5gnyj/5G/nEejPOoB5xH
flFPYNQP8o37IX+oFzDqA/nE/ZEf1AMY+Ue+EB/EH/kGI7/IB+LXZRfXrnWU
eH+hH9VDmXGvZ3Wx8As7jvQ/cOXzAv029+DbWXLjDra4/41Ioy+9+X3RX7nb
AyuuRtaxYx9VbDx/RMbvh35Z2W8ZGptTzfpS7OOrDvry+6D++4t1Tm6UlDGl
TCineM2+Rj0/WT0rzcyvgEWHOC/u/0Kzj1Gfht3rTXquRjL9oXuprvcE2tSk
O7Ohrput0K45sOCBC614ac5m6u9kCzeF6tU+5U63lo4VB73TxpKsL5pWzfSk
hhMjzSGlrczz7invtBlelOpun3FTu4mtSyj8oneWN9U8u+t2r0MjG+w/2er7
hIzSLV58VF95mU3VcxicPuBDrweVPM7TqWKSzNFzbzf6kfv5+NSNQT+yqr22
9nqKP99X+WZGYz9+y97rGkg0TFCQboDPrbAXvxXyt1WFpyxTEj2cP+33wVLh
bLJ9eFyCkt6rTFz/LFXyfTo1oDp7z3fVwp6ZtuObsjX7NWxkptUjC81+sQ03
CclbrZnf2DdvBPxnZU9qN0uzTSpNU7vw+Yl+0hW+SUg808nf/wPZnbUHb1xn
ldUrJMxQs7+LdEKK56zS7G/s89BxH/8I72t8n8+Z47AvMbqF7fm1fmRgjWa/
+2SsX7QgTLPfse83vP9a3kB9E9/3Uwp0Hd0eNjJ1caijToJm/6OfR9eFxZV4
NrDAlAo7nRQp7y/0b2tJYJtHcC2TfC4Zn53jw/sJ/frEUpc1KcMV7J9dudbm
+/14/6A/O8Oso0r+UcK0gntC6iw18w/9GL1sc0x6+lG2Oujd/RcH5fx9tL39
nqrOXfM+QT/On1XbecHrKN+Pz9w45eS2tUwYukVnLfWcyeOlx6f2/NTD1lqf
XVKl7ULR9muNVt/pYsv/2PHu00+60bjFuMzatoPtNM9rsp/lQVEmpUVpmdfZ
M5V2maFzV5Ezize6/t9mdrz9g6hXHnlRBttRkRbayI7/oHg6a6qUjAffWqoS
6tlH+lG9ro9klD/7nLfe72pmfeZw0b1eX9LRH7NSWZSzkICqB/2F/qTvHzBj
2RPnmNHx3fMDiuR07HHMq3pm+5jTiNmHlxcq6JI02HqsY69gEtqWtXtYTkdM
dx45rR0pRN7Mry5pV1BQ3yplRHqh8GbRrafuxCtpSn55YMTLmveQ8VWrZGrt
YUNBOWk9D53pj8Yco0Kp5v3TbFKwZEzVw6w2+JW+LNW8h74qaM4NDlFSeZKh
eWZ0uXD5xA+5JyP//v65Zf5F1sDWNrao/bb67KduNCyr6Z7u386WJj7IN//M
jfTvbGjz+PP9U+b0064r5pr3Vdxn2x4v7FdQ39OZQ8m93wvh1T/dHdFVUvGC
uKcKUzXvo8zcNVZj490seFhbXZCnIPsOj0Vbz5/h79G2c7F3ppucE7wPz1Xd
L9W8n5pmxUsG92neT3hPfSw/UfNH2ynhuYjyfYPdCv6e0tvUMM/NXfOeGt5W
X2a1g2g42fL+sZBuZjXV+Fjoxy60fGG6lkV0Fyvdee7mmu2uND/I2CNCr5N5
fiLccNrtTVN3d3pVOf85r5O2GCjjpKR7z2heqqyOFT3qT2S7ZBS/sdws7kEN
KwoPCt8S7UPzUqyTL969xDzNdVIC3/WlQ+oFJ5eYV7DVrnGv/SvYj77qc4qJ
Nb3A7jdsm/2c1J82B39oUBhYzF7QL9H+fracTPsc3ac1nGal3s+e1v1MTsor
xYaFoUfYtNbbWbW/y0n1VYTp2MFXWaXH9thdKR6U2nZXb3XONeazaOGiA3tX
UfQY/WjzoIm1x3erlvsraLZWDWU7ZQlf9jYecspT0hVZxP3ktktCQobNvgUp
7rT2rUBJXMINtk7XoKgjzZPOpK+7Pb2zhYUFBTh27/aiJIsNMfbzrrL/Aex+
Ldg=
    "], {{
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNlnmUj2UUx++LshukMPZljKVQiqEwsmQmEolSpEkRISW0z0QqRnbCZIks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          "]], 
         PolygonBox[CompressedData["
1:eJwtk1tLlFEUhvenlVpWZqZWlvonvBC66sYLr0qwTNRGC82ckULRURMGESIY
gmFAgvB3VGhqpajdlIh28BSZp7ISyisPz2K/Fw/vWrP3N986vF9xKHItnOKc
K4Uj8APOB849QW/AJlwiT6JVMAlp5B1oJ0zDN6iHZpiCRbgNTTABJ7nfhV6H
bSgmH0SrYR0ukj9Fb8Ix4qPQRtwOo1BAnkCvwgr8h3t653vYhQaohB0IuN9q
Cu+giOA5Wg5v4DL5AFoGy6rZag3BTyjk/Bl6C76rx2a9YwjyOX+MlsAC/ING
9fwaLnAeR684X4T1ZL1E4BXkkffbPThFnA09xHfhDPEHtMX537ICf8fOuuEA
Tgc+DmuW4+ptUL3+Uu3W89nAP2N3H6m3t+rdetzXTmwX92EWZlRrLXyCXJ7p
QysghTgVHhI/cL7WP3BHNX+VR8wbdeapQDtx/pnfsKd32TPHOciEKHGNdrMl
rw1o9xvyRkKzX9WubQcZ5OmBn6V58gWcI4/ZbLWbL6qlUd5Z0q7NQ+b1Ye3S
PG9eH5PXktrlmvPfQlyzeKn/tpmYd0e0a/NwDvlH9dLrvJf/KjZPnwj8TmwX
UdU67/y3EZM3PmvW5pE5zdxmbd/QIWxPbOE=
          "]]}]}, {}, {}, {}, {}}, 
     {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwt0skyXGEAhuHWaNFtjBiDaESysczOysZClcINqHIBSFXuw1W4CFNIkEkG
8zxLzGMMSQjJc4rFU+///ZvuOufEW9ub2xJCoVAnLwnOHcwEZ+OnJmkiYWbt
dH2vc+Q6d+sZPeTZ8/qBBfLtXj2njwd2Kil8tJeocl7UC5Ypt1f0E2s8s1f1
knUq7A0d5TvP7U39xWd+UOCuX3/zmkJ7S7+wTZE9oH8Y5LG9o1/Zpdh+o1e8
pcTe02/sU2oP6TXDPLEPdIxDyuwR/cs74vaR3nLDMZXuTnScbOeHZJBFJv/c
52iMNKJMuHukp5qskYS7lzYp0zx1ntIWmnlFE400UE8dtdTwgurgvwTPKHi3
pBEjSmrwzkghEvxm8D2QSBfh++/mPxq9SLk=
       "]]}}]},
  AspectRatio->1,
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"tan \\!\\(\\*OverscriptBox[\\(\[Beta]\\), \\(_\\)]\\)\"", 
     TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[OverscriptBox[\\(\[Eta]\\), \\(_\\)], \
\\(b\\)]\\)\"", TraditionalForm]},
  Method->{},
  PlotLabel->FormBox[
   "\"\[Sigma](\\!\\(\\*SubscriptBox[\\(y\\), \\(b\\)]\\)) / \
\\!\\(\\*SubscriptBox[\\(y\\), \\(b\\)]\\)\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"Local",
WindowSize->{881, 1028},
WindowMargins->{{Automatic, 201}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
CellContext->Notebook,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 153, 3, 207, "Title"],
Cell[735, 27, 570, 9, 405, "Section"],
Cell[CellGroupData[{
Cell[1330, 40, 77, 1, 51, "Section"],
Cell[CellGroupData[{
Cell[1432, 45, 146, 2, 71, "Subsection"],
Cell[1581, 49, 123, 3, 32, "Input"],
Cell[1707, 54, 139, 3, 28, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1883, 62, 2014, 69, 219, "Subsection"],
Cell[3900, 133, 7101, 176, 689, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11038, 314, 754, 27, 70, "Subsection"],
Cell[11795, 343, 713, 20, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12545, 368, 555, 20, 70, "Subsection"],
Cell[CellGroupData[{
Cell[13125, 392, 1044, 27, 70, "Input"],
Cell[14172, 421, 7559, 137, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21780, 564, 219, 9, 70, "Subsection"],
Cell[CellGroupData[{
Cell[22024, 577, 1857, 45, 70, "Input"],
Cell[23884, 624, 43745, 757, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67678, 1387, 314, 12, 70, "Subsection"],
Cell[CellGroupData[{
Cell[68017, 1403, 1766, 43, 70, "Input"],
Cell[69786, 1448, 45245, 780, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

